@@ -467,13 +467,6 @@ enum {
   SPVM_OPCODE_C_ID_GET_STACK_MULNUM_LONG,
   SPVM_OPCODE_C_ID_GET_STACK_MULNUM_FLOAT,
   SPVM_OPCODE_C_ID_GET_STACK_MULNUM_DOUBLE,
-  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_BYTE,
-  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_SHORT,
-  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_INT,
-  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_LONG,
-  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_FLOAT,
-  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_DOUBLE,
-  SPVM_OPCODE_C_ID_GET_STACK_OPTIONAL_OBJECT,
   SPVM_OPCODE_C_ID_SET_STACK_BYTE,
   SPVM_OPCODE_C_ID_SET_STACK_SHORT,
   SPVM_OPCODE_C_ID_SET_STACK_INT,
